-- don't load if class is wrong
local _, class = UnitClass("player")
if class ~= "WARLOCK" then return end

-- make sure clcInfo is loaded
if not clcInfo then return end

-- exposed vars

local modName = "_destruction_"

local mod, options, baseMod, db, tdb

-- some lazy staic numbers
local MAX_PRIORITY = 12

local function GetDB(info)
	return db[info[5]]
end
local function SetDB(info, val)
	db[info[5]] = val
end

local function GetTDB(info)
	return tdb[info[#info]]
end

local function SetTDB(info, val)
	tdb[info[#info]] = val
end

local function GetPriority(info)
	local i = tonumber(info[#info])
	return db.priority[i]
end

local function SetPriority(info, val)
	local i = tonumber(info[#info])
	db.priority[i] = val
	baseMod:UpdatePriorityQueue()
end

spellChoice = { none = "None" }

local function LoadModule()
	mod = clcInfo_Options
	options = mod.options
	baseMod = clcInfo.classModules[modName]
	db = clcInfo:RegisterClassModuleDB(modName)
	tdb = clcInfo:RegisterClassModuleTDB(modName)

	for alias, name in pairs(baseMod.actionsName) do
		spellChoice[alias] = name
	end

	options.args.classModules.args[modName] = {
		order = 4, type = "group", childGroups = "tab", name = "Destruction",
		args = {
			tabGeneral = {
				order = 1, type = "group", name = "General", args = {
					igVarious = {
						order = 1, type = "group", inline = true, name = "Prediction",
						args = {
							overview = {
								order = 1, type = "description", name = "NOTE: this module calculates spell cast time and travel time dynamically.\n These setting are for additional reminder time.\nSpells near the front of the priority list will need minimal additional reminder time.\n\n",
							},
							clipISF = {
								order = 3, type = "range", min = 0, max = 3, step = 0.01, name = "Improved Soul Fire",
								get = GetDB, set = SetDB,
							},
							_clipISF = {
								order = 4, type = "description", width = "double", name = "Additional reminder time for Improved Soul Fire buff",
							},
							_x1 = {
								order = 5, type = "description", name = "\n",
							},

							clipImmolate = {
								order = 6, type = "range", min = 0, max = 3, step = 0.01, name = "Immolate",
								get = GetDB, set = SetDB,
							},
							_clipImmolate = {
								order = 7, type = "description", width = "double", name = "Additional reminder time for Immolate debuff.",
							},
							_x2 = {
								order = 8, type = "description", name = "\n",
							},
							clipCorruption = {
								order = 9, type = "range", min = 0, max = 3, step = 0.01, name = "Corruption",
								get = GetDB, set = SetDB,
							},
							_clipCorruption = {
								order = 10, type = "description", width = "double", name = " Additional reminder time for Corruption debuff.",
							},
							_x3 = {
								order = 11, type = "description", name = "\n",
							},
							debuffDelay = {
								order = 12, type = "range", min = 0, max = 2, step = 0.01, name = "Debuff application delay",
								get = GetDB, set = SetDB,
							},
							_debuffDelay = {
								order = 13, type = "description", width = "double", name = " Time needed in seconds for debuff to show on your target.",
							},
						},
					},
				},
			},
			tabPriority = { order = 2, type = "group", name = "Priority", args = {} },
		},
	}
	
	-- filler selection
	local args = options.args.classModules.args[modName].args.tabPriority.args
	for i = 1, MAX_PRIORITY do
		args[tostring(i)] = {
			order = i, type = "select", name = tostring(i), 
			get = GetPriority, set = SetPriority, values = spellChoice,
		}
	end
	
end

-- function needs to be added to a clcInfo table, that stores the functions to be called when Options are loaded
clcInfo.optionsCMLoaders[#(clcInfo.optionsCMLoaders) + 1] = LoadModule
